package
Version:
v0.2.8
Opens a new window with list of versions in this module.
Published: Oct 26, 2025
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type HttpServerConfig struct {
Host string `config:"HTTP_BIND_ADDRESS" default:"0.0.0.0"`
Port int `config:"HTTP_BIND_PORT" default:"8080"`
AllowedOrigins string `config:"HTTP_ALLOWED_ORIGINS" default:"*"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.